require 'spec_helper'

describe 'local_rpm_repo' do
  context 'valid parameters' do
    # Assign values to non-default parameters
    let(:params) do
      {
        'mirror_fqdn'     => 'yum.example.com',
        'source_base_url' => 'http://bin.example.com/',
        'repo_list'       => {
          'repo1' => {
            'version' => '1.0.0.0',
          },
        },
      }
    end

    # Ensure compilation works for each supported OS
    on_supported_os.each do |os, os_facts|
      context "on #{os}" do
        let(:facts) { os_facts }

        # Ensure it compiles
        it { is_expected.to compile.with_all_deps }

        # Ensure the vhost is created
        it { is_expected.to contain_apache__vhost('yum.example.com') }

        # We should also have a repo direcetory named repo1
        it {
          is_expected.to contain_file('create_repo1').with(
            ensure: 'directory',
            path: '/var/yumrepos/repo1/versions/1.0.0.0',
            owner: 'root',
            group: 'root',
          )
        }

        # A temp file should be downloaded for this repo
        it {
          is_expected.to contain_exec('wget_repo1').with(
            command: '/usr/bin/wget http://bin.example.com//repo1-1.0.0.0.tar -O /tmp/repo1-1.0.0.0.tar',
            onlyif: '/bin/test -n "$(/bin/find /var/yumrepos/repo1/versions/1.0.0.0 -maxdepth 0 -type d -empty 2>/dev/null)"',
            creates: '/tmp/repo1-1.0.0.0.tar',
          )
        }

        # The tar should be extracted
        it {
          is_expected.to contain_exec('extract_repo1').with(
            command: '/bin/tar -xvf /tmp/repo1-1.0.0.0.tar',
            cwd: '/var/yumrepos/repo1/versions/1.0.0.0',
          )
        }
      end
    end
  end
end
